<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html" version="4.0" encoding="UTF-8" />

  <xsl:attribute-set name="table">
    <xsl:attribute name="bgcolor">#9999ff</xsl:attribute>
    <xsl:attribute name="width">75%</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="tableheader">
    <xsl:attribute name="bgcolor">#ffffcc</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="tablerow">
    <xsl:attribute name="bgcolor">#ccccff</xsl:attribute>
  </xsl:attribute-set>

  <xsl:param name="sortkey" />
  <xsl:param name="order">ascending</xsl:param>

  <xsl:template match="/">
    <html>
    <body>
      <xsl:apply-templates>
        <xsl:with-param name="sortkey" select="$sortkey" />
        <xsl:with-param name="order" select="$order" />
      </xsl:apply-templates>
    </body>
    </html>
  </xsl:template>

  <xsl:template match="wines">
    <xsl:param name="sortkey" />
    <xsl:param name="order">ascending</xsl:param>
    <table xsl:use-attribute-sets="table">
      <xsl:call-template name="wineheader" />
      <xsl:choose>
        <xsl:when test="$sortkey">
          <xsl:apply-templates select="wine">
            <xsl:sort select="attribute::*[name() = $sortkey]"
                      order="{$order}" />
          </xsl:apply-templates>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="wine">
            <xsl:sort select="." order="{$order}" />
          </xsl:apply-templates>
        </xsl:otherwise>
      </xsl:choose>
    </table>
  </xsl:template>

  <xsl:template name="wineheader">
    <tr xsl:use-attribute-sets="tableheader">
      <td>Name</td>
      <td>Origin</td>
      <td>Year</td>
      <td>Color</td>
      <td>Type</td>
    </tr>
  </xsl:template>

  <xsl:template match="wine">
    <tr xsl:use-attribute-sets="tablerow">
      <td><xsl:value-of select="." /></td>
      <td><xsl:value-of select="@origin" /></td>
      <td><xsl:value-of select="@year" /></td>
      <td><xsl:value-of select="@color" /></td>
      <td><xsl:value-of select="@type" /></td>
    </tr>
  </xsl:template>
</xsl:stylesheet>
